@@ -17,3 +17,8 @@ class ContextField(enum.Enum):
     PushConfig = "push_config"
     PushConfigKeyword = "push_config_keyword"
     SourceKeywordOffset = "source_keyword_offset"
+
+class WebDriverType(enum.Enum):
+    CHROME = "chrome"
+    FIREFOX = "firefox"
+    EDGE = "edge"
